@@ -10,8 +10,12 @@ import dascore.compat as compat
 from dascore.constants import PatchType
 from dascore.exceptions import FilterValueError
 from dascore.proc.filter import _get_sampling_rate, _lowpass_cheby_2
-from dascore.utils.misc import check_evenly_sampled, get_dim_value_from_kwargs
-from dascore.utils.patch import get_start_stop_step, patch_function
+from dascore.utils.misc import check_evenly_sampled
+from dascore.utils.patch import (
+    get_dim_value_from_kwargs,
+    get_start_stop_step,
+    patch_function,
+)
 from dascore.utils.time import to_number, to_timedelta64
 
 
@@ -51,7 +55,9 @@ def decimate(
         sr = _get_sampling_rate(patch, dim)
         freq = sr * 0.5 / float(factor)
         fdata = _lowpass_cheby_2(patch.data, freq, sr, axis=axis)
-        patch = dascore.Patch(fdata, coords=patch.coords, attrs=patch.attrs)
+        patch = dascore.Patch(
+            fdata, coords=patch.coords, attrs=patch.attrs, dims=patch.dims
+        )
 
     kwargs = {dim: slice(None, None, factor)}
     dar = patch._data_array.sel(**kwargs)
@@ -63,7 +69,7 @@ def decimate(
     d_attr = f"d_{dim}"
     attrs[d_attr] = patch.attrs[d_attr] * factor
 
-    return dascore.Patch(data=data, coords=dar.coords, attrs=dar.attrs)
+    return dascore.Patch(data=data, coords=dar.coords, attrs=dar.attrs, dims=dar.dims)
 
 
 @patch_function()
