@@ -33,6 +33,7 @@ from dascore.constants import (
 )
 from dascore.core.schema import PatchSummaryWithHistory
 from dascore.exceptions import PatchAttributeError, PatchDimError
+from dascore.utils.coords import Coords
 from dascore.utils.docs import compose_docstring, format_dtypes
 from dascore.utils.misc import append_func
 from dascore.utils.time import to_datetime64, to_timedelta64
@@ -40,41 +41,6 @@ from dascore.utils.time import to_datetime64, to_timedelta64
 attr_type = Union[Dict[str, Any], str, Sequence[str], None]
 
 
-class Coords:
-    """A wrapper around xarray coords for a bit more intuitive access."""
-
-    def __init__(self, coords):
-        self._coords = coords
-
-    def __getitem__(self, item):
-        """Return the raw numpy array."""
-        out = self._coords[item]
-        return getattr(out, "values", out)
-
-    def __str__(self):
-        return str(self._coords)
-
-    __repr__ = __str__
-
-    def get(self, item):
-        """Return item or None if not in coord. Same as dict.get"""
-        return self._coords.get(item)
-
-    def __iter__(self):
-        return self._coords.__iter__()
-
-    @property
-    def timedelta64(self):
-        """Return time deltas of time dimension."""
-        time = self._coords["time"]
-        return time - time[0]
-
-    @property
-    def datetime64(self):
-        """Return datetime64 of time dimension."""
-        return self._coords["time"]
-
-
 def _shallow_copy(patch: PatchType) -> PatchType:
     """
     Shallow copy patch so data array, attrs, and history can be changed.
@@ -280,8 +246,8 @@ class _AttrsCoordsMixer:
         if not dims and coords:
             dims = list(coords)
         self.attrs = attrs if attrs is not None else {}
-        self.coords = coords
-        self.dims = dims
+        self.coords = Coords(coords)
+        self.dims = dims if dims is not None else ()
         self._original_attrs = attrs
         self._original_coords = coords
         # fill missing values with default or implicit values
@@ -341,11 +307,11 @@ class _AttrsCoordsMixer:
         if len(match_dims):
             assert len(match_dims) == 1
             dim = match_dims[0]
-            coord = self.coords.get(dim, None)
+            coord = self.coords.get(dim)
             coord_min = self.attrs[f"{dim}_min"]
             if coord is not None and np.min(coord) != coord_min:
                 td = coord - coord[0]
-                self.copied_coords[dim] = coord_min + td
+                self.coords = self.coords.update(**{dim: coord_min + td})
 
     @append_func(set_attr_funcs["*_max"])
     def _update_min_from_max(self, match_dims=()):
@@ -368,7 +334,7 @@ class _AttrsCoordsMixer:
             time_max = self.attrs[f"{dim}_max"]
             if coord is not None and np.max(coord) != time_max:
                 td = coord - coord[-1]
-                self.copied_coords[dim] = time_max + td
+                self.coords = self.coords.update(**{dim: time_max + td})
 
     @append_func(set_attr_funcs["d_*"])
     def _update_max_from_d(self, match_dims=()):
@@ -394,7 +360,7 @@ class _AttrsCoordsMixer:
             start = self.copied_attrs.get(f"{dim}_min", None)
             if coord is not None and start is not None:
                 new_coord = start + np.arange(len(coord)) * d_dim
-                self.copied_coords[dim] = new_coord
+                self.coords = self.coords.update(**{dim: new_coord})
 
     @functools.cached_property
     def copied_attrs(self):
@@ -405,14 +371,8 @@ class _AttrsCoordsMixer:
     @functools.cached_property
     def copied_coords(self):
         """Make a copy of the coords before mutating."""
-        coords = self.coords
-        if isinstance(coords, Coords):  # unpack coordinates
-            coords = coords._coords
         # TODO I don't like having this deep copy but shallow still caused
-        # mutations so I will leave it for now.
-        coords = copy.deepcopy(coords)
-        self.coords = coords
-        return coords
+        return copy.deepcopy(self.coords)
 
     def __call__(self, *args, **kwargs):
         return self.attrs, self.coords
@@ -452,8 +412,7 @@ class _AttrsCoordsMixer:
 
     def update_coords(self, **kwargs):
         """Update the coordinates based on kwarg inputs."""
-        for key, value in kwargs.items():
-            self.copied_coords[key] = value
+        self.coords = self.coords.update(**kwargs)
         self._condition_coords()
         self._update_attrs_from_coords()
 
@@ -473,7 +432,7 @@ class _AttrsCoordsMixer:
         if not np.issubdtype(time.dtype, np.datetime64):
             td = to_timedelta64(time)
             time = start_time + td
-        self.copied_coords["time"] = time
+        self.coords = self.coords.update(time=time)
 
     def _set_attr_types(self):
         """Make sure time attrs are expected types"""
@@ -501,7 +460,7 @@ def patches_to_df(
         {fields}
     plus a field called 'patch' which contains a reference to each patch.
     """
-    if isinstance(patches, dascore.MemorySpool):
+    if isinstance(patches, dascore.BaseSpool):
         df = patches._df
     elif isinstance(patches, pd.DataFrame):
         return patches
@@ -523,7 +482,7 @@ def merge_patches(
     tolerance: float = 1.5,
 ) -> Sequence[PatchType]:
     """
-    Merge all compatible patches in stream together.
+    Merge all compatible patches in spool or patch list together.
 
     Parameters
     ----------
@@ -645,3 +604,26 @@ def get_default_patch_name(patch):
     sta = attrs.get("station", "")
     tag = attrs.get("tag", "")
     return f"DAS__{net}__{sta}__{tag}__{start}__{end}"
+
+
+def get_dim_value_from_kwargs(patch, kwargs):
+    """
+    Assert that kwargs contain one value and it is a dimension of patch.
+
+    Several patch functions allow passing values via kwargs which are dimension
+    specific. This function allows for some sane validation of such functions.
+
+    Return the name of the dimension, its axis position, and its value.
+    """
+    dims = patch.dims
+    overlap = set(dims) & set(kwargs)
+    if len(kwargs) != 1 or not overlap:
+        msg = (
+            "You must use exactly one dimension name in kwargs. "
+            f"You passed the following kwargs: {kwargs} to a patch with "
+            f"dimensions {patch.dims}"
+        )
+        raise PatchDimError(msg)
+    dim = list(overlap)[0]
+    axis = dims.index(dim)
+    return dim, axis, kwargs[dim]
