@@ -3,33 +3,29 @@ pytest configuration for dascore
 """
 import shutil
 from pathlib import Path
-from uuid import uuid1
 
 import numpy as np
 import pytest
 import tables as tb
 
-import dascore
+import dascore as dc
 import dascore.examples as ex
 from dascore.clients.dirspool import DirectorySpool
-from dascore.core import MemorySpool, Patch
+from dascore.constants import SpoolType
+from dascore.core import Patch
 from dascore.io.core import read
 from dascore.utils.downloader import fetch
 from dascore.utils.misc import register_func
 
 test_data_path = Path(__file__).parent.absolute() / "test_data"
 
-STREAM_FIXTURES = []
+# A list to register functions that return general spools or patches
+# These are to be used for running many different patches/spools through
+# Generic tests.
+SPOOL_FIXTURES = []
 PATCH_FIXTURES = []
 
 
-def _save_patch(patch, base_path, file_format="dasdae"):
-    """Save the patch based on start_time network, station, tag."""
-    path = base_path / (f"{uuid1()}.hdf5")
-    patch.io.write(path, file_format=file_format)
-    return path
-
-
 # --- Pytest configuration
 
 
@@ -72,10 +68,6 @@ def pytest_collection_modifyitems(config, items):
             item.add_marker(marks[mark_name])
 
 
-# --- Test fixtures
-FILE_SPOOLS = []
-
-
 def pytest_sessionstart(session):
     """
     Hook to run before any other tests.
@@ -92,6 +84,9 @@ def pytest_sessionstart(session):
     dc._debug = True
 
 
+# --- Patch Paths
+
+
 @pytest.fixture(scope="session")
 def terra15_das_example_path():
     """Return the path to the example terra15 file."""
@@ -100,17 +95,10 @@ def terra15_das_example_path():
     return out
 
 
-@pytest.fixture()
-@register_func(STREAM_FIXTURES)
-def terra15_das_stream(terra15_das_example_path) -> MemorySpool:
-    """Return the stream of Terra15 Das Array"""
-    return read(terra15_das_example_path, file_format="terra15")
-
-
 @pytest.fixture(scope="session")
-@register_func(STREAM_FIXTURES)
+@register_func(SPOOL_FIXTURES)
 def terra15_das_unfinished_path() -> Path:
-    """Return the stream of Terra15 Das Array"""
+    """Return the spool of Terra15 Das Array"""
     out = fetch("terra15_das_unfinished.hdf5")
     assert out.exists()
     return out
@@ -122,6 +110,16 @@ def terra15_v5_path():
     return fetch("terra15_v5_test_file.hdf5")
 
 
+@pytest.fixture()
+@register_func(SPOOL_FIXTURES)
+def terra15_das_spool(terra15_das_example_path) -> SpoolType:
+    """Return the spool of Terra15 Das Array"""
+    return read(terra15_das_example_path, file_format="terra15")
+
+
+# --- Patch fixtures
+
+
 @pytest.fixture(scope="session")
 @register_func(PATCH_FIXTURES)
 def terra15_das_patch(terra15_das_example_path) -> Patch:
@@ -142,66 +140,41 @@ def random_patch() -> Patch:
     return get_example_patch("random_das")
 
 
-@pytest.fixture(scope="session")
-@register_func(STREAM_FIXTURES)
-def random_spool() -> MemorySpool:
-    """Init a random array."""
-    from dascore.examples import get_example_spool
-
-    return get_example_spool("random_das")
+@pytest.fixture(scope="class")
+@register_func(PATCH_FIXTURES)
+def random_patch_with_lat_lon(random_patch):
+    """Get a random patch with added lat/lon coordinates."""
+    return dc.get_example_patch("random_patch_with_lat_lon")
 
 
-@pytest.fixture(scope="session", params=PATCH_FIXTURES)
+@pytest.fixture(scope="class")
+@register_func(PATCH_FIXTURES)
+def multi_dim_coords_patch(random_patch):
+    """A patch with a multiple dimensional coord."""
+    dist = random_patch.coords["distance"]
+    time = random_patch.coords["time"]
+    quality = np.ones((len(dist), len(time)))
+    out = random_patch.assign_coords(quality=(("distance", "time"), quality))
+    return out
+
+
+@pytest.fixture(scope="class", params=PATCH_FIXTURES)
 def patch(request):
     """A meta-fixtures for collecting all patches used in testing."""
     return request.getfixturevalue(request.param)
 
 
-@pytest.fixture(scope="class")
-def dummy_text_file(tmp_path_factory):
-    """Return a text file with silliness in it."""
-    parent = tmp_path_factory.mktemp("dummy")
-    path = parent / "hello.txt"
-    path.write_text("Clearly not a hdf5 file. Or is it?")
-    return path
-
-
-@pytest.fixture(scope="class")
-def adjacent_spool_no_overlap(random_patch) -> dascore.MemorySpool:
-    """
-    Create a stream with several patches within one time sample but not
-    overlapping.
-    """
-    pa1 = random_patch
-    t2 = random_patch.attrs["time_max"]
-    d_time = random_patch.attrs["d_time"]
-
-    pa2 = random_patch.update_attrs(time_min=t2 + d_time)
-    t3 = pa2.attrs["time_max"]
-
-    pa3 = pa2.update_attrs(time_min=t3 + d_time)
-
-    expected_time = pa3.attrs["time_max"] - pa1.attrs["time_min"]
-    actual_time = pa3.coords["time"].max() - pa1.coords["time"].min()
-    assert expected_time == actual_time
-    return dascore.MemorySpool([pa2, pa1, pa3])
+# --- Spool setup fixtures
 
 
 @pytest.fixture(scope="class")
 def one_file_dir(tmp_path_factory, random_patch):
     """Create a directory with a single DAS file."""
     out = Path(tmp_path_factory.mktemp("one_file_file_spool"))
-    spool = dascore.MemorySpool([random_patch])
+    spool = dc.spool(random_patch)
     return ex.spool_to_directory(spool, path=out)
 
 
-@pytest.fixture(scope="class")
-@register_func(FILE_SPOOLS)
-def one_file_file_spool(one_file_dir):
-    """Create a directory with a single DAS file."""
-    return DirectorySpool(one_file_dir).update()
-
-
 @pytest.fixture(scope="class")
 def two_patch_directory(tmp_path_factory, terra15_das_example_path, random_patch):
     """Create a directory of DAS files for testing."""
@@ -213,12 +186,6 @@ def two_patch_directory(tmp_path_factory, terra15_das_example_path, random_patch
     return dir_path
 
 
-@pytest.fixture(scope="class")
-def diverse_spool():
-    """Create a spool with a diverse set of patches for testing."""
-    return ex._diverse_spool()
-
-
 @pytest.fixture(scope="class")
 def diverse_spool_directory(diverse_spool):
     """Save the diverse spool contents to a directory."""
@@ -229,30 +196,90 @@ def diverse_spool_directory(diverse_spool):
 
 
 @pytest.fixture(scope="class")
+def adjacent_spool_directory(tmp_path_factory, adjacent_spool_no_overlap):
+    """Create a directory of diverse DAS files for testing."""
+
+    # create a directory with several patch files in it.
+    dir_path = Path(tmp_path_factory.mktemp("data"))
+    for num, patch in adjacent_spool_no_overlap:
+        path = dir_path / f"{num}_patch.hdf5"
+        dc.write(patch, path, file_format="dasdae")
+    return dir_path
+
+
+# --- Spool fixtures
+
+
+@pytest.fixture(scope="session")
+@register_func(SPOOL_FIXTURES)
+def random_spool() -> SpoolType:
+    """Init a random array."""
+    from dascore.examples import get_example_spool
+
+    return get_example_spool("random_das")
+
+
+@pytest.fixture(scope="class")
+@register_func(SPOOL_FIXTURES)
+def adjacent_spool_no_overlap(random_patch) -> dc.BaseSpool:
+    """
+    Create a spool with several patches within one time sample but not
+    overlapping.
+    """
+    pa1 = random_patch
+    t2 = random_patch.attrs["time_max"]
+    d_time = random_patch.attrs["d_time"]
+
+    pa2 = random_patch.update_attrs(time_min=t2 + d_time)
+    t3 = pa2.attrs["time_max"]
+
+    pa3 = pa2.update_attrs(time_min=t3 + d_time)
+
+    expected_time = pa3.attrs["time_max"] - pa1.attrs["time_min"]
+    actual_time = pa3.coords["time"].max() - pa1.coords["time"].min()
+    assert expected_time == actual_time
+    return dc.spool([pa2, pa1, pa3])
+
+
+@pytest.fixture(scope="class")
+@register_func(SPOOL_FIXTURES)
+def one_file_file_spool(one_file_dir):
+    """Create a directory with a single DAS file."""
+    return DirectorySpool(one_file_dir).update()
+
+
+@pytest.fixture(scope="class")
+@register_func(SPOOL_FIXTURES)
+def diverse_spool():
+    """Create a spool with a diverse set of patches for testing."""
+    return ex._diverse_spool()
+
+
+@pytest.fixture(scope="class")
+@register_func(SPOOL_FIXTURES)
 def diverse_directory_spool(diverse_spool_directory):
     """Save the diverse spool contents to a directory."""
-    out = dascore.spool(diverse_spool_directory).update()
+    out = dc.spool(diverse_spool_directory).update()
     return out
 
 
 @pytest.fixture(scope="class")
-def adjacent_spool_directory(tmp_path_factory, adjacent_spool_no_overlap):
-    """Create a directory of diverse DAS files for testing."""
-    # create a directory with several patch files in it.
-    dir_path = tmp_path_factory.mktemp("data")
-    for patch in adjacent_spool_no_overlap:
-        _save_patch(patch, dir_path)
-    return dir_path
-
-
-@pytest.fixture(scope="class")
-@register_func(FILE_SPOOLS)
+@register_func(SPOOL_FIXTURES)
 def basic_file_spool(two_patch_directory):
     """Return a DAS bank on basic_bank_directory."""
     out = DirectorySpool(two_patch_directory)
     return out.update()
 
 
+@pytest.fixture(scope="class", params=SPOOL_FIXTURES)
+def spool(request):
+    """A meta-fixtures for collecting all spools used in testing."""
+    return request.getfixturevalue(request.param)
+
+
+# --- Misc. test fixtures
+
+
 @pytest.fixture
 def generic_hdf5(tmp_path):
     """
@@ -267,3 +294,12 @@ def generic_hdf5(tmp_path):
         group = fi.create_group("/", "bob")
         fi.create_carray(group, "data", obj=np.random.rand(10))
     return path
+
+
+@pytest.fixture(scope="class")
+def dummy_text_file(tmp_path_factory):
+    """Return a text file with silliness in it."""
+    parent = tmp_path_factory.mktemp("dummy")
+    path = parent / "hello.txt"
+    path.write_text("Clearly not a hdf5 file. Or is it?")
+    return path
